summaryrefslogtreecommitdiffstats
path: root/xmrstak/backend/amd
diff options
context:
space:
mode:
authorpsychocrypt <psychocrypt@users.noreply.github.com>2017-10-27 20:50:51 +0200
committerpsychocrypt <psychocrypt@users.noreply.github.com>2017-10-27 21:40:38 +0200
commit3e091d9251bf0d67c27efa5183d24cff7cbe9b50 (patch)
tree1fe67113efda926b59969b5525ac7cdaad1563b2 /xmrstak/backend/amd
parentc192b97b67bf648540bf058f21b7873bfe886a82 (diff)
downloadxmr-stak-3e091d9251bf0d67c27efa5183d24cff7cbe9b50.zip
xmr-stak-3e091d9251bf0d67c27efa5183d24cff7cbe9b50.tar.gz
increase safety memory for autosuggestion
- increase safty memory from 64 to 128 MiB - NVIDIA: increase lmem reserve per thread to 1kiB
Diffstat (limited to 'xmrstak/backend/amd')
-rw-r--r--xmrstak/backend/amd/autoAdjust.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/xmrstak/backend/amd/autoAdjust.hpp b/xmrstak/backend/amd/autoAdjust.hpp
index 87e6299..8f9aa50 100644
--- a/xmrstak/backend/amd/autoAdjust.hpp
+++ b/xmrstak/backend/amd/autoAdjust.hpp
@@ -97,8 +97,8 @@ private:
int i = 0;
for(auto& ctx : devVec)
{
- // keep 64MiB memory free (value is randomly chosen)
- size_t availableMem = ctx.freeMem - (64u * 1024 * 1024);
+ // keep 128MiB memory free (value is randomly chosen)
+ size_t availableMem = ctx.freeMem - (128u * byteToMiB);
// 224byte extra memory is used per thread for meta data
size_t perThread = hashMemSize + 224u;
size_t max_intensity = availableMem / perThread;
OpenPOWER on IntegriCloud